diff --git a/jOOQ/src/main/java/org/jooq/impl/DSL.java b/jOOQ/src/main/java/org/jooq/impl/DSL.java
index af558ac7e7..68ad946f1c 100644
--- a/jOOQ/src/main/java/org/jooq/impl/DSL.java
+++ b/jOOQ/src/main/java/org/jooq/impl/DSL.java
@@ -20247,6 +20247,9 @@ public class DSL {
+
+
+
diff --git a/jOOQ/src/main/resources/xsd/jooq-runtime-3.14.0.xsd b/jOOQ/src/main/resources/xsd/jooq-runtime-3.14.0.xsd
index d364602c8b..77ff6b763f 100644
--- a/jOOQ/src/main/resources/xsd/jooq-runtime-3.14.0.xsd
+++ b/jOOQ/src/main/resources/xsd/jooq-runtime-3.14.0.xsd
@@ -216,12 +216,13 @@ this flag enables the transformation to ANSI join syntax.
This feature is available in the commercial distribution only.]]>
-
In Oracle 11g and less,
This feature is available in the commercial distribution only.]]>LIMIT clauses or ROW_NUMBER() expressions.
ROWNUM filtering was the most popular way to paginate. This pseudo
-column is not supported in other RDBMS, and should be replaced in Oracle 12c by the FETCH clause. This
-transformation allows for replacing such a filter by equivalent SQL, if possible.
+column is not supported in other RDBMS, and should be replaced in Oracle 12c by the FETCH clause or
+ROW_NUMBER() OVER () filtering. This transformation allows for replacing such a filter by
+equivalent SQL, if possible.
diff --git a/jOOQ/src/main/java/org/jooq/conf/Settings.java b/jOOQ/src/main/java/org/jooq/conf/Settings.java
index b142df9b86..35e66d06db 100644
--- a/jOOQ/src/main/java/org/jooq/conf/Settings.java
+++ b/jOOQ/src/main/java/org/jooq/conf/Settings.java
@@ -95,7 +95,7 @@ public class Settings
@XmlElement(defaultValue = "false")
protected Boolean transformTableListsToAnsiJoin = false;
@XmlElement(defaultValue = "false")
- protected Boolean transformRownumToLimit = false;
+ protected Boolean transformRownum = false;
@XmlElement(defaultValue = "NEVER")
@XmlSchemaType(name = "string")
protected TransformUnneededArithmeticExpressions transformUnneededArithmeticExpressions = TransformUnneededArithmeticExpressions.NEVER;
@@ -853,8 +853,9 @@ public class Settings
* Transform ROWNUM expressions to corresponding LIMIT clauses or ROW_NUMBER() expressions.
*
* In Oracle 11g and less, ROWNUM filtering was the most popular way to paginate. This pseudo
- * column is not supported in other RDBMS, and should be replaced in Oracle 12c by the FETCH clause. This
- * transformation allows for replacing such a filter by equivalent SQL, if possible.
+ * column is not supported in other RDBMS, and should be replaced in Oracle 12c by the FETCH clause or
+ * ROW_NUMBER() OVER () filtering. This transformation allows for replacing such a filter by
+ * equivalent SQL, if possible.
*
* This feature is available in the commercial distribution only.
*
@@ -863,20 +864,20 @@ public class Settings
* {@link Boolean }
*
*/
- public Boolean isTransformRownumToLimit() {
- return transformRownumToLimit;
+ public Boolean isTransformRownum() {
+ return transformRownum;
}
/**
* Sets the value of the transformRownumToLimit property.
*
* @param value
* allowed object is
* {@link Boolean }
*
*/
- public void setTransformRownumToLimit(Boolean value) {
- this.transformRownumToLimit = value;
+ public void setTransformRownum(Boolean value) {
+ this.transformRownum = value;
}
/**
@@ -2464,8 +2465,8 @@ public class Settings
return this;
}
- public Settings withTransformRownumToLimit(Boolean value) {
- setTransformRownumToLimit(value);
+ public Settings withTransformRownum(Boolean value) {
+ setTransformRownum(value);
return this;
}
@@ -3055,7 +3056,7 @@ public class Settings
builder.append("fetchTriggerValuesAfterSQLServerOutput", fetchTriggerValuesAfterSQLServerOutput);
builder.append("transformAnsiJoinToTableLists", transformAnsiJoinToTableLists);
builder.append("transformTableListsToAnsiJoin", transformTableListsToAnsiJoin);
- builder.append("transformRownumToLimit", transformRownumToLimit);
+ builder.append("transformRownum", transformRownum);
builder.append("transformUnneededArithmeticExpressions", transformUnneededArithmeticExpressions);
builder.append("backslashEscaping", backslashEscaping);
builder.append("paramType", paramType);
@@ -3362,12 +3363,12 @@ public class Settings
return false;
}
}
- if (transformRownumToLimit == null) {
- if (other.transformRownumToLimit!= null) {
+ if (transformRownum == null) {
+ if (other.transformRownum!= null) {
return false;
}
} else {
- if (!transformRownumToLimit.equals(other.transformRownumToLimit)) {
+ if (!transformRownum.equals(other.transformRownum)) {
return false;
}
}
@@ -4023,7 +4024,7 @@ public class Settings
result = ((prime*result)+((fetchTriggerValuesAfterSQLServerOutput == null)? 0 :fetchTriggerValuesAfterSQLServerOutput.hashCode()));
result = ((prime*result)+((transformAnsiJoinToTableLists == null)? 0 :transformAnsiJoinToTableLists.hashCode()));
result = ((prime*result)+((transformTableListsToAnsiJoin == null)? 0 :transformTableListsToAnsiJoin.hashCode()));
- result = ((prime*result)+((transformRownumToLimit == null)? 0 :transformRownumToLimit.hashCode()));
+ result = ((prime*result)+((transformRownum == null)? 0 :transformRownum.hashCode()));
result = ((prime*result)+((transformUnneededArithmeticExpressions == null)? 0 :transformUnneededArithmeticExpressions.hashCode()));
result = ((prime*result)+((backslashEscaping == null)? 0 :backslashEscaping.hashCode()));
result = ((prime*result)+((paramType == null)? 0 :paramType.hashCode()));
@@ -863,20 +864,20 @@ public class Settings
}
/**
- * Sets the value of the transformRownumToLimit property.
+ * Sets the value of the transformRownum property.
*
* @param value